/****************************************************************************
** Meta object code from reading C++ file 'kmahjongg.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kmahjongg-17.08.3/src/kmahjongg.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmahjongg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMahjongg_t {
    QByteArrayData data[31];
    char stringdata0[325];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMahjongg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMahjongg_t qt_meta_stringdata_KMahjongg = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KMahjongg"
QT_MOC_LITERAL(1, 10, 12), // "startNewGame"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 3), // "num"
QT_MOC_LITERAL(4, 28, 12), // "loadSettings"
QT_MOC_LITERAL(5, 41, 14), // "showStatusText"
QT_MOC_LITERAL(6, 56, 3), // "msg"
QT_MOC_LITERAL(7, 60, 5), // "board"
QT_MOC_LITERAL(8, 66, 14), // "showItemNumber"
QT_MOC_LITERAL(9, 81, 7), // "maximum"
QT_MOC_LITERAL(10, 89, 7), // "current"
QT_MOC_LITERAL(11, 97, 4), // "left"
QT_MOC_LITERAL(12, 102, 8), // "gameOver"
QT_MOC_LITERAL(13, 111, 10), // "numRemoved"
QT_MOC_LITERAL(14, 122, 6), // "cheats"
QT_MOC_LITERAL(15, 129, 27), // "demoOrMoveListAnimationOver"
QT_MOC_LITERAL(16, 157, 12), // "demoGameLost"
QT_MOC_LITERAL(17, 170, 12), // "showSettings"
QT_MOC_LITERAL(18, 183, 15), // "startNewNumeric"
QT_MOC_LITERAL(19, 199, 8), // "saveGame"
QT_MOC_LITERAL(20, 208, 8), // "loadGame"
QT_MOC_LITERAL(21, 217, 11), // "restartGame"
QT_MOC_LITERAL(22, 229, 4), // "undo"
QT_MOC_LITERAL(23, 234, 4), // "redo"
QT_MOC_LITERAL(24, 239, 5), // "pause"
QT_MOC_LITERAL(25, 245, 8), // "demoMode"
QT_MOC_LITERAL(26, 254, 11), // "displayTime"
QT_MOC_LITERAL(27, 266, 10), // "timestring"
QT_MOC_LITERAL(28, 277, 14), // "showHighscores"
QT_MOC_LITERAL(29, 292, 15), // "slotBoardEditor"
QT_MOC_LITERAL(30, 308, 16) // "noMovesAvailable"

    },
    "KMahjongg\0startNewGame\0\0num\0loadSettings\0"
    "showStatusText\0msg\0board\0showItemNumber\0"
    "maximum\0current\0left\0gameOver\0numRemoved\0"
    "cheats\0demoOrMoveListAnimationOver\0"
    "demoGameLost\0showSettings\0startNewNumeric\0"
    "saveGame\0loadGame\0restartGame\0undo\0"
    "redo\0pause\0demoMode\0displayTime\0"
    "timestring\0showHighscores\0slotBoardEditor\0"
    "noMovesAvailable"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMahjongg[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x0a /* Public */,
       1,    0,  117,    2, 0x2a /* Public | MethodCloned */,
       4,    0,  118,    2, 0x0a /* Public */,
       5,    2,  119,    2, 0x0a /* Public */,
       8,    3,  124,    2, 0x0a /* Public */,
      12,    2,  131,    2, 0x0a /* Public */,
      15,    1,  136,    2, 0x0a /* Public */,
      17,    0,  139,    2, 0x08 /* Private */,
      18,    0,  140,    2, 0x08 /* Private */,
      19,    0,  141,    2, 0x08 /* Private */,
      20,    0,  142,    2, 0x08 /* Private */,
      21,    0,  143,    2, 0x08 /* Private */,
      22,    0,  144,    2, 0x08 /* Private */,
      23,    0,  145,    2, 0x08 /* Private */,
      24,    0,  146,    2, 0x08 /* Private */,
      25,    0,  147,    2, 0x08 /* Private */,
      26,    1,  148,    2, 0x08 /* Private */,
      28,    0,  151,    2, 0x08 /* Private */,
      29,    0,  152,    2, 0x08 /* Private */,
      30,    0,  153,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Long,    6,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   11,
    QMetaType::Void, QMetaType::UShort, QMetaType::UShort,   13,   14,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KMahjongg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMahjongg *_t = static_cast<KMahjongg *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->startNewGame((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->startNewGame(); break;
        case 2: _t->loadSettings(); break;
        case 3: _t->showStatusText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< long(*)>(_a[2]))); break;
        case 4: _t->showItemNumber((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->gameOver((*reinterpret_cast< unsigned short(*)>(_a[1])),(*reinterpret_cast< unsigned short(*)>(_a[2]))); break;
        case 6: _t->demoOrMoveListAnimationOver((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->showSettings(); break;
        case 8: _t->startNewNumeric(); break;
        case 9: _t->saveGame(); break;
        case 10: _t->loadGame(); break;
        case 11: _t->restartGame(); break;
        case 12: _t->undo(); break;
        case 13: _t->redo(); break;
        case 14: _t->pause(); break;
        case 15: _t->demoMode(); break;
        case 16: _t->displayTime((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->showHighscores(); break;
        case 18: _t->slotBoardEditor(); break;
        case 19: _t->noMovesAvailable(); break;
        default: ;
        }
    }
}

const QMetaObject KMahjongg::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KMahjongg.data,
      qt_meta_data_KMahjongg,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMahjongg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMahjongg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMahjongg.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KMahjongg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
