#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'gametype.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GAMETYPE_H
#define UI_GAMETYPE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_KMahjonggLayoutSelector
{
public:
    QGridLayout *gridLayout_2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_RandomLayout;
    QWidget *widgetNoRandom;
    QGridLayout *gridLayout;
    QVBoxLayout *layoutNoRandom;
    QHBoxLayout *_2;
    QVBoxLayout *_3;
    QListWidget *layoutList;
    QPushButton *getNewButton;
    QGroupBox *groupBox_2;
    QVBoxLayout *_4;
    QLabel *layoutPreview;
    QGroupBox *groupBox;
    QHBoxLayout *_5;
    QVBoxLayout *_6;
    QLabel *labelAuthor;
    QLabel *labelContact;
    QLabel *labelDescription;
    QVBoxLayout *_7;
    QLabel *layoutAuthor;
    QLabel *layoutContact;
    QLabel *layoutDescription;
    QSpacerItem *spacerItem;
    KLineEdit *kcfg_Layout;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *KMahjonggLayoutSelector)
    {
        if (KMahjonggLayoutSelector->objectName().isEmpty())
            KMahjonggLayoutSelector->setObjectName(QStringLiteral("KMahjonggLayoutSelector"));
        KMahjonggLayoutSelector->resize(480, 461);
        KMahjonggLayoutSelector->setMaximumSize(QSize(800, 600));
        gridLayout_2 = new QGridLayout(KMahjonggLayoutSelector);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        kcfg_RandomLayout = new QCheckBox(KMahjonggLayoutSelector);
        kcfg_RandomLayout->setObjectName(QStringLiteral("kcfg_RandomLayout"));

        verticalLayout_2->addWidget(kcfg_RandomLayout);

        widgetNoRandom = new QWidget(KMahjonggLayoutSelector);
        widgetNoRandom->setObjectName(QStringLiteral("widgetNoRandom"));
        gridLayout = new QGridLayout(widgetNoRandom);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        layoutNoRandom = new QVBoxLayout();
        layoutNoRandom->setObjectName(QStringLiteral("layoutNoRandom"));
        _2 = new QHBoxLayout();
        _2->setObjectName(QStringLiteral("_2"));
        _3 = new QVBoxLayout();
        _3->setObjectName(QStringLiteral("_3"));
        layoutList = new QListWidget(widgetNoRandom);
        layoutList->setObjectName(QStringLiteral("layoutList"));
        layoutList->setMinimumSize(QSize(120, 0));

        _3->addWidget(layoutList);

        getNewButton = new QPushButton(widgetNoRandom);
        getNewButton->setObjectName(QStringLiteral("getNewButton"));

        _3->addWidget(getNewButton);


        _2->addLayout(_3);

        groupBox_2 = new QGroupBox(widgetNoRandom);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        _4 = new QVBoxLayout(groupBox_2);
#ifndef UI_Q_OS_MAC
        _4->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        _4->setContentsMargins(9, 9, 9, 9);
#endif
        _4->setObjectName(QStringLiteral("_4"));
        layoutPreview = new QLabel(groupBox_2);
        layoutPreview->setObjectName(QStringLiteral("layoutPreview"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(layoutPreview->sizePolicy().hasHeightForWidth());
        layoutPreview->setSizePolicy(sizePolicy);
        layoutPreview->setMinimumSize(QSize(240, 180));

        _4->addWidget(layoutPreview);


        _2->addWidget(groupBox_2);


        layoutNoRandom->addLayout(_2);

        groupBox = new QGroupBox(widgetNoRandom);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        _5 = new QHBoxLayout(groupBox);
#ifndef UI_Q_OS_MAC
        _5->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        _5->setContentsMargins(9, 9, 9, 9);
#endif
        _5->setObjectName(QStringLiteral("_5"));
        _6 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        _6->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        _6->setContentsMargins(0, 0, 0, 0);
#endif
        _6->setObjectName(QStringLiteral("_6"));
        labelAuthor = new QLabel(groupBox);
        labelAuthor->setObjectName(QStringLiteral("labelAuthor"));
        labelAuthor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _6->addWidget(labelAuthor);

        labelContact = new QLabel(groupBox);
        labelContact->setObjectName(QStringLiteral("labelContact"));
        labelContact->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _6->addWidget(labelContact);

        labelDescription = new QLabel(groupBox);
        labelDescription->setObjectName(QStringLiteral("labelDescription"));
        labelDescription->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _6->addWidget(labelDescription);


        _5->addLayout(_6);

        _7 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        _7->setSpacing(6);
#endif
        _7->setContentsMargins(0, 0, 0, 0);
        _7->setObjectName(QStringLiteral("_7"));
        layoutAuthor = new QLabel(groupBox);
        layoutAuthor->setObjectName(QStringLiteral("layoutAuthor"));

        _7->addWidget(layoutAuthor);

        layoutContact = new QLabel(groupBox);
        layoutContact->setObjectName(QStringLiteral("layoutContact"));

        _7->addWidget(layoutContact);

        layoutDescription = new QLabel(groupBox);
        layoutDescription->setObjectName(QStringLiteral("layoutDescription"));

        _7->addWidget(layoutDescription);


        _5->addLayout(_7);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _5->addItem(spacerItem);


        layoutNoRandom->addWidget(groupBox);

        kcfg_Layout = new KLineEdit(widgetNoRandom);
        kcfg_Layout->setObjectName(QStringLiteral("kcfg_Layout"));
        kcfg_Layout->setEnabled(false);
        kcfg_Layout->setFrame(false);
        kcfg_Layout->setReadOnly(false);

        layoutNoRandom->addWidget(kcfg_Layout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        layoutNoRandom->addItem(spacerItem1);


        gridLayout->addLayout(layoutNoRandom, 0, 0, 1, 1);


        verticalLayout_2->addWidget(widgetNoRandom);


        gridLayout_2->addLayout(verticalLayout_2, 0, 0, 1, 1);


        retranslateUi(KMahjonggLayoutSelector);
        QObject::connect(kcfg_RandomLayout, SIGNAL(toggled(bool)), KMahjonggLayoutSelector, SLOT(useRandomLayoutToggled(bool)));

        QMetaObject::connectSlotsByName(KMahjonggLayoutSelector);
    } // setupUi

    void retranslateUi(QWidget *KMahjonggLayoutSelector)
    {
        kcfg_RandomLayout->setText(tr2i18n("Random Layout", Q_NULLPTR));
        getNewButton->setText(tr2i18n("&Get New Layouts", Q_NULLPTR));
        groupBox_2->setTitle(tr2i18n("Preview", Q_NULLPTR));
        groupBox->setTitle(tr2i18n("Layout Details", Q_NULLPTR));
        labelAuthor->setText(tr2i18n("Author:", Q_NULLPTR));
        labelContact->setText(tr2i18n("Contact:", Q_NULLPTR));
        labelDescription->setText(tr2i18n("Description:", Q_NULLPTR));
        layoutAuthor->setText(QString());
        layoutContact->setText(QString());
        layoutDescription->setText(QString());
        Q_UNUSED(KMahjonggLayoutSelector);
    } // retranslateUi

};

namespace Ui {
    class KMahjonggLayoutSelector: public Ui_KMahjonggLayoutSelector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GAMETYPE_H

