/****************************************************************************
** Meta object code from reading C++ file 'gameview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kmahjongg-17.08.3/src/gameview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gameview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_GameView_t {
    QByteArrayData data[41];
    char stringdata0[517];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_GameView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_GameView_t qt_meta_stringdata_GameView = {
    {
QT_MOC_LITERAL(0, 0, 8), // "GameView"
QT_MOC_LITERAL(1, 9, 17), // "newGameCalculated"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 17), // "statusTextChanged"
QT_MOC_LITERAL(4, 46, 4), // "text"
QT_MOC_LITERAL(5, 51, 10), // "gameNumber"
QT_MOC_LITERAL(6, 62, 17), // "itemNumberChanged"
QT_MOC_LITERAL(7, 80, 10), // "maxItemNum"
QT_MOC_LITERAL(8, 91, 7), // "itemNum"
QT_MOC_LITERAL(9, 99, 9), // "moveCount"
QT_MOC_LITERAL(10, 109, 8), // "gameOver"
QT_MOC_LITERAL(11, 118, 12), // "removedItems"
QT_MOC_LITERAL(12, 131, 10), // "cheatsUsed"
QT_MOC_LITERAL(13, 142, 27), // "demoOrMoveListAnimationOver"
QT_MOC_LITERAL(14, 170, 12), // "demoGameLost"
QT_MOC_LITERAL(15, 183, 16), // "noMovesAvailable"
QT_MOC_LITERAL(16, 200, 16), // "addItemAndUpdate"
QT_MOC_LITERAL(17, 217, 9), // "POSITION&"
QT_MOC_LITERAL(18, 227, 9), // "stItemPos"
QT_MOC_LITERAL(19, 237, 10), // "removeItem"
QT_MOC_LITERAL(20, 248, 9), // "startDemo"
QT_MOC_LITERAL(21, 258, 14), // "angleSwitchCCW"
QT_MOC_LITERAL(22, 273, 13), // "angleSwitchCW"
QT_MOC_LITERAL(23, 287, 13), // "createNewGame"
QT_MOC_LITERAL(24, 301, 7), // "shuffle"
QT_MOC_LITERAL(25, 309, 8), // "helpMove"
QT_MOC_LITERAL(26, 318, 9), // "helpMatch"
QT_MOC_LITERAL(27, 328, 14), // "GameItem*const"
QT_MOC_LITERAL(28, 343, 8), // "gameItem"
QT_MOC_LITERAL(29, 352, 22), // "startMoveListAnimation"
QT_MOC_LITERAL(30, 375, 17), // "clearSelectedTile"
QT_MOC_LITERAL(31, 393, 7), // "addItem"
QT_MOC_LITERAL(32, 401, 11), // "updateImage"
QT_MOC_LITERAL(33, 413, 11), // "updateOrder"
QT_MOC_LITERAL(34, 425, 14), // "updatePosition"
QT_MOC_LITERAL(35, 440, 9), // "GameItem*"
QT_MOC_LITERAL(36, 450, 12), // "demoGameOver"
QT_MOC_LITERAL(37, 463, 3), // "won"
QT_MOC_LITERAL(38, 467, 23), // "changeItemSelectedState"
QT_MOC_LITERAL(39, 491, 8), // "selected"
QT_MOC_LITERAL(40, 500, 16) // "selectionChanged"

    },
    "GameView\0newGameCalculated\0\0"
    "statusTextChanged\0text\0gameNumber\0"
    "itemNumberChanged\0maxItemNum\0itemNum\0"
    "moveCount\0gameOver\0removedItems\0"
    "cheatsUsed\0demoOrMoveListAnimationOver\0"
    "demoGameLost\0noMovesAvailable\0"
    "addItemAndUpdate\0POSITION&\0stItemPos\0"
    "removeItem\0startDemo\0angleSwitchCCW\0"
    "angleSwitchCW\0createNewGame\0shuffle\0"
    "helpMove\0helpMatch\0GameItem*const\0"
    "gameItem\0startMoveListAnimation\0"
    "clearSelectedTile\0addItem\0updateImage\0"
    "updateOrder\0updatePosition\0GameItem*\0"
    "demoGameOver\0won\0changeItemSelectedState\0"
    "selected\0selectionChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_GameView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  159,    2, 0x06 /* Public */,
       3,    2,  160,    2, 0x06 /* Public */,
       6,    3,  165,    2, 0x06 /* Public */,
      10,    2,  172,    2, 0x06 /* Public */,
      13,    1,  177,    2, 0x06 /* Public */,
      15,    0,  180,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    1,  181,    2, 0x0a /* Public */,
      19,    1,  184,    2, 0x0a /* Public */,
      20,    0,  187,    2, 0x0a /* Public */,
      21,    0,  188,    2, 0x0a /* Public */,
      22,    0,  189,    2, 0x0a /* Public */,
      23,    1,  190,    2, 0x0a /* Public */,
      23,    0,  193,    2, 0x2a /* Public | MethodCloned */,
      24,    0,  194,    2, 0x0a /* Public */,
      25,    0,  195,    2, 0x0a /* Public */,
      26,    1,  196,    2, 0x0a /* Public */,
      29,    0,  199,    2, 0x0a /* Public */,
      30,    0,  200,    2, 0x0a /* Public */,
      31,    4,  201,    2, 0x08 /* Private */,
      31,    3,  210,    2, 0x28 /* Private | MethodCloned */,
      31,    2,  217,    2, 0x28 /* Private | MethodCloned */,
      31,    1,  222,    2, 0x28 /* Private | MethodCloned */,
      31,    4,  225,    2, 0x08 /* Private */,
      31,    3,  234,    2, 0x28 /* Private | MethodCloned */,
      31,    2,  241,    2, 0x28 /* Private | MethodCloned */,
      31,    1,  246,    2, 0x28 /* Private | MethodCloned */,
      36,    1,  249,    2, 0x08 /* Private */,
      38,    2,  252,    2, 0x08 /* Private */,
      40,    0,  257,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Long,    4,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    7,    8,    9,
    QMetaType::Void, QMetaType::UShort, QMetaType::UShort,   11,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Long,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,   18,   32,   33,   34,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Bool, QMetaType::Bool,   18,   32,   33,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Bool,   18,   32,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 35, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,   28,   32,   33,   34,
    QMetaType::Void, 0x80000000 | 35, QMetaType::Bool, QMetaType::Bool,   28,   32,   33,
    QMetaType::Void, 0x80000000 | 35, QMetaType::Bool,   28,   32,
    QMetaType::Void, 0x80000000 | 35,   28,
    QMetaType::Void, QMetaType::Bool,   37,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Bool,   18,   39,
    QMetaType::Void,

       0        // eod
};

void GameView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        GameView *_t = static_cast<GameView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newGameCalculated(); break;
        case 1: _t->statusTextChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< long(*)>(_a[2]))); break;
        case 2: _t->itemNumberChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->gameOver((*reinterpret_cast< unsigned short(*)>(_a[1])),(*reinterpret_cast< unsigned short(*)>(_a[2]))); break;
        case 4: _t->demoOrMoveListAnimationOver((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->noMovesAvailable(); break;
        case 6: _t->addItemAndUpdate((*reinterpret_cast< POSITION(*)>(_a[1]))); break;
        case 7: _t->removeItem((*reinterpret_cast< POSITION(*)>(_a[1]))); break;
        case 8: _t->startDemo(); break;
        case 9: _t->angleSwitchCCW(); break;
        case 10: _t->angleSwitchCW(); break;
        case 11: _t->createNewGame((*reinterpret_cast< long(*)>(_a[1]))); break;
        case 12: _t->createNewGame(); break;
        case 13: _t->shuffle(); break;
        case 14: _t->helpMove(); break;
        case 15: _t->helpMatch((*reinterpret_cast< const GameItem*const(*)>(_a[1]))); break;
        case 16: _t->startMoveListAnimation(); break;
        case 17: _t->clearSelectedTile(); break;
        case 18: _t->addItem((*reinterpret_cast< POSITION(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 19: _t->addItem((*reinterpret_cast< POSITION(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 20: _t->addItem((*reinterpret_cast< POSITION(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 21: _t->addItem((*reinterpret_cast< POSITION(*)>(_a[1]))); break;
        case 22: _t->addItem((*reinterpret_cast< GameItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 23: _t->addItem((*reinterpret_cast< GameItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 24: _t->addItem((*reinterpret_cast< GameItem*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 25: _t->addItem((*reinterpret_cast< GameItem*(*)>(_a[1]))); break;
        case 26: _t->demoGameOver((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->changeItemSelectedState((*reinterpret_cast< POSITION(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 28: _t->selectionChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (GameView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::newGameCalculated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(const QString & , long );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::statusTextChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(int , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::itemNumberChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(unsigned short , unsigned short );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::gameOver)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (GameView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::demoOrMoveListAnimationOver)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (GameView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&GameView::noMovesAvailable)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject GameView::staticMetaObject = {
    { &QGraphicsView::staticMetaObject, qt_meta_stringdata_GameView.data,
      qt_meta_data_GameView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *GameView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GameView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_GameView.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int GameView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void GameView::newGameCalculated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GameView::statusTextChanged(const QString & _t1, long _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void GameView::itemNumberChanged(int _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void GameView::gameOver(unsigned short _t1, unsigned short _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void GameView::demoOrMoveListAnimationOver(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void GameView::noMovesAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
