/****************************************************************************
** Meta object code from reading C++ file 'editor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kmahjongg-17.08.3/src/editor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Editor_t {
    QByteArrayData data[15];
    char stringdata0[203];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Editor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Editor_t qt_meta_stringdata_Editor = {
    {
QT_MOC_LITERAL(0, 0, 6), // "Editor"
QT_MOC_LITERAL(1, 7, 22), // "setTilesetFromSettings"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 24), // "drawFrameMousePressEvent"
QT_MOC_LITERAL(4, 56, 12), // "QMouseEvent*"
QT_MOC_LITERAL(5, 69, 24), // "drawFrameMouseMovedEvent"
QT_MOC_LITERAL(6, 94, 9), // "loadBoard"
QT_MOC_LITERAL(7, 104, 9), // "saveBoard"
QT_MOC_LITERAL(8, 114, 8), // "newBoard"
QT_MOC_LITERAL(9, 123, 13), // "slotShiftLeft"
QT_MOC_LITERAL(10, 137, 14), // "slotShiftRight"
QT_MOC_LITERAL(11, 152, 11), // "slotShiftUp"
QT_MOC_LITERAL(12, 164, 13), // "slotShiftDown"
QT_MOC_LITERAL(13, 178, 15), // "slotModeChanged"
QT_MOC_LITERAL(14, 194, 8) // "QAction*"

    },
    "Editor\0setTilesetFromSettings\0\0"
    "drawFrameMousePressEvent\0QMouseEvent*\0"
    "drawFrameMouseMovedEvent\0loadBoard\0"
    "saveBoard\0newBoard\0slotShiftLeft\0"
    "slotShiftRight\0slotShiftUp\0slotShiftDown\0"
    "slotModeChanged\0QAction*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Editor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x0a /* Public */,
       3,    1,   70,    2, 0x09 /* Protected */,
       5,    1,   73,    2, 0x09 /* Protected */,
       6,    0,   76,    2, 0x09 /* Protected */,
       7,    0,   77,    2, 0x09 /* Protected */,
       8,    0,   78,    2, 0x09 /* Protected */,
       9,    0,   79,    2, 0x09 /* Protected */,
      10,    0,   80,    2, 0x09 /* Protected */,
      11,    0,   81,    2, 0x09 /* Protected */,
      12,    0,   82,    2, 0x09 /* Protected */,
      13,    1,   83,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,    2,

       0        // eod
};

void Editor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Editor *_t = static_cast<Editor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setTilesetFromSettings(); break;
        case 1: _t->drawFrameMousePressEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 2: _t->drawFrameMouseMovedEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 3: _t->loadBoard(); break;
        case 4: { bool _r = _t->saveBoard();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->newBoard(); break;
        case 6: _t->slotShiftLeft(); break;
        case 7: _t->slotShiftRight(); break;
        case 8: _t->slotShiftUp(); break;
        case 9: _t->slotShiftDown(); break;
        case 10: _t->slotModeChanged((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject Editor::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Editor.data,
      qt_meta_data_Editor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Editor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Editor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Editor.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Editor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
